@@ -9,10 +9,14 @@ from os.path import exists
 from os.path import join
 from pprint import pformat
 from typing import Any
+from typing import Awaitable
+from typing import Deque
 from typing import Dict
 from typing import Iterator
 from typing import Optional
 from typing import Tuple
+from typing import Type
+from typing import TypeVar
 from typing import Union
 from typing import cast
 
@@ -31,7 +35,10 @@ from dipdup.config import OperationIndexConfig
 from dipdup.config import PostgresDatabaseConfig
 from dipdup.config import ResolvedIndexConfigT
 from dipdup.config import TzktDatasourceConfig
+from dipdup.datasources.coinbase.datasource import CoinbaseDatasource
 from dipdup.datasources.datasource import Datasource
+from dipdup.datasources.ipfs.datasource import IpfsDatasource
+from dipdup.datasources.metadata.datasource import MetadataDatasource
 from dipdup.datasources.tzkt.datasource import TzktDatasource
 from dipdup.enums import ReindexingAction
 from dipdup.enums import ReindexingReasonC
@@ -49,10 +56,14 @@ from dipdup.models import Index
 from dipdup.models import ReindexingReason
 from dipdup.models import Schema
 from dipdup.utils import FormattedLogger
+from dipdup.utils import slowdown
 from dipdup.utils.database import execute_sql_scripts
 from dipdup.utils.database import wipe_schema
 
+DatasourceT = TypeVar('DatasourceT', bound=Datasource)
+# NOTE: Dependency cycle
 pending_indexes = deque()  # type: ignore
+pending_hooks: Deque[Awaitable[None]] = deque()
 
 
 # TODO: Dataclasses are cool, everyone loves them. Resolve issue with pydantic serialization.
@@ -75,6 +86,7 @@ class DipDupContext:
         self,
         name: str,
         fmt: Optional[str] = None,
+        wait: bool = True,
         *args,
         **kwargs: Any,
     ) -> None:
@@ -183,9 +195,7 @@ class DipDupContext:
         index: Union[OperationIndex, BigMapIndex, HeadIndex]
 
         datasource_name = cast(TzktDatasourceConfig, index_config.datasource).name
-        datasource = self.datasources[datasource_name]
-        if not isinstance(datasource, TzktDatasource):
-            raise RuntimeError(f'`{datasource_name}` is not a TzktDatasource')
+        datasource = self.get_tzkt_datasource(datasource_name)
 
         if isinstance(index_config, OperationIndexConfig):
             index = OperationIndex(self, index_config, datasource)
@@ -204,6 +214,26 @@ class DipDupContext:
         # NOTE: IndexDispatcher will handle further initialization when it's time
         pending_indexes.append(index)
 
+    def _get_datasource(self, name: str, type_: Type[DatasourceT]) -> DatasourceT:
+        datasource = self.datasources.get(name)
+        if not datasource:
+            raise ConfigurationError(f'Datasource `{name}` is missing')
+        if not isinstance(datasource, type_):
+            raise ConfigurationError(f'Datasource `{name}` is not a `{type.__name__}`')
+        return datasource
+
+    def get_tzkt_datasource(self, name: str) -> TzktDatasource:
+        return self._get_datasource(name, TzktDatasource)
+
+    def get_coinbase_datasource(self, name: str) -> CoinbaseDatasource:
+        return self._get_datasource(name, CoinbaseDatasource)
+
+    def get_metadata_datasource(self, name: str) -> MetadataDatasource:
+        return self._get_datasource(name, MetadataDatasource)
+
+    def get_ipfs_datasource(self, name: str) -> IpfsDatasource:
+        return self._get_datasource(name, IpfsDatasource)
+
 
 class HookContext(DipDupContext):
     """Hook callback context."""
@@ -260,6 +290,12 @@ class CallbackManager:
         self._handlers: Dict[Tuple[str, str], HandlerConfig] = {}
         self._hooks: Dict[str, HookConfig] = {}
 
+    async def run(self) -> None:
+        while True:
+            async with slowdown(1):
+                while coro := pending_hooks.popleft():
+                    await coro
+
     def register_handler(self, handler_config: HandlerConfig) -> None:
         if not handler_config.parent:
             raise RuntimeError('Handler must have a parent index')
@@ -295,7 +331,7 @@ class CallbackManager:
             handler_config=handler_config,
             datasource=datasource,
         )
-        with self._wrapper('handler', name):
+        with self._callback_wrapper('handler', name):
             await handler_config.callback_fn(new_ctx, *args, **kwargs)
 
     async def fire_hook(
@@ -303,6 +339,7 @@ class CallbackManager:
         ctx: 'DipDupContext',
         name: str,
         fmt: Optional[str] = None,
+        wait: bool = True,
         *args,
         **kwargs: Any,
     ) -> None:
@@ -316,8 +353,15 @@ class CallbackManager:
         )
 
         self._verify_arguments(new_ctx, *args, **kwargs)
-        with self._wrapper('hook', name):
-            await hook_config.callback_fn(ctx, *args, **kwargs)
+
+        async def _wrapper():
+            with self._callback_wrapper('hook', name):
+                await hook_config.callback_fn(ctx, *args, **kwargs)
+
+        if wait:
+            await _wrapper()
+        else:
+            pending_hooks.append(_wrapper())
 
     async def execute_sql(self, ctx: 'DipDupContext', name: str) -> None:
         """Execute SQL included with project"""
@@ -335,7 +379,7 @@ class CallbackManager:
         await execute_sql_scripts(connection, sql_path)
 
     @contextmanager
-    def _wrapper(self, kind: str, name: str) -> Iterator[None]:
+    def _callback_wrapper(self, kind: str, name: str) -> Iterator[None]:
         try:
             start = time.perf_counter()
             yield
